@@ -152,16 +152,21 @@ with open(opereto_config_file, 'r') as f:
 
 OPERETO_HOST = opereto_credentials_json['opereto_host']
 
-
 def get_opereto_client():
-    OPERETO_TOKEN = opereto_credentials_json['opereto_token']
-    client = OperetoClient(opereto_host=OPERETO_HOST, opereto_token=OPERETO_TOKEN)
-    return client
+    if opereto_credentials_json.get('opereto_password'):
+        client = OperetoClient(opereto_host=opereto_credentials_json['opereto_host'],
+                               opereto_user=opereto_credentials_json['opereto_user'],
+                               opereto_password=opereto_credentials_json['opereto_password'])
+        return client
+    else:
+        OPERETO_TOKEN = opereto_credentials_json['opereto_token']
+        client = OperetoClient(opereto_host=OPERETO_HOST, opereto_token=OPERETO_TOKEN)
+        return client
 
 
 def print_token(params):
     client = get_opereto_client()
-    print(client.get_current_opereto_token)
+    print(client.get_current_username)
 
 def local(cmd, working_directory=os.getcwd()):
     print(cmd)
@@ -393,7 +398,7 @@ def local_dev(params):
     elif params['create']:
 
         delete_local_dev_config()
-        _user = client.get_current_opereto_token
+        _user = client.get_current_username
         parent_process_title = params['--title'] or 'Developer parent flow for user: {}'.format(_user['username'])
         ppid = client.create_process('local_dev_parent_flow', title=parent_process_title, agent='any', mode='development')
         client.wait_to_start(ppid)
